# Uptimes

A small python3 package for uptimes.

How to Install :

```
pip install uptimes==0.1.0
```

Usage :

```
import uptimes.uptimes
import time

time.sleep(10)
print(uptimes.uptimes.uptimes())
```

Output:

```
**0** days **0** hours **0** minutes **10** seconds
```